==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/CrossReferences.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class CrossReferences extends GenericDPSObject {
    /**
     * CROSS_REFERENCES.PKTABLE_CATALOG
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String pktableCatalog;

    /**
     * CROSS_REFERENCES.PKTABLE_SCHEMA
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String pktableSchema;

    /**
     * CROSS_REFERENCES.PKTABLE_NAME
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String pktableName;

    /**
     * CROSS_REFERENCES.PKCOLUMN_NAME
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String pkcolumnName;

    /**
     * CROSS_REFERENCES.FKTABLE_CATALOG
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String fktableCatalog;

    /**
     * CROSS_REFERENCES.FKTABLE_SCHEMA
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String fktableSchema;

    /**
     * CROSS_REFERENCES.FKTABLE_NAME
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String fktableName;

    /**
     * CROSS_REFERENCES.FKCOLUMN_NAME
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String fkcolumnName;

    /**
     * CROSS_REFERENCES.ORDINAL_POSITION
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private Short ordinalPosition;

    /**
     * CROSS_REFERENCES.UPDATE_RULE
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private Short updateRule;

    /**
     * CROSS_REFERENCES.DELETE_RULE
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private Short deleteRule;

    /**
     * CROSS_REFERENCES.FK_NAME
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String fkName;

    /**
     * CROSS_REFERENCES.PK_NAME
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private String pkName;

    /**
     * CROSS_REFERENCES.DEFERRABILITY
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private Short deferrability;

    /**
     * @mbggenerated 2014-03-10 10:45:44
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return CROSS_REFERENCES.PKTABLE_CATALOG
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getPktableCatalog() {
        return pktableCatalog;
    }

    /**
     * CROSS_REFERENCES.PKTABLE_CATALOG
     *
     * @param pktableCatalog
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setPktableCatalog(String pktableCatalog) {
        this.pktableCatalog = pktableCatalog == null ? null : pktableCatalog.trim();
    }

    /**
     * @return CROSS_REFERENCES.PKTABLE_SCHEMA
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getPktableSchema() {
        return pktableSchema;
    }

    /**
     * CROSS_REFERENCES.PKTABLE_SCHEMA
     *
     * @param pktableSchema
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setPktableSchema(String pktableSchema) {
        this.pktableSchema = pktableSchema == null ? null : pktableSchema.trim();
    }

    /**
     * @return CROSS_REFERENCES.PKTABLE_NAME
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getPktableName() {
        return pktableName;
    }

    /**
     * CROSS_REFERENCES.PKTABLE_NAME
     *
     * @param pktableName
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setPktableName(String pktableName) {
        this.pktableName = pktableName == null ? null : pktableName.trim();
    }

    /**
     * @return CROSS_REFERENCES.PKCOLUMN_NAME
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getPkcolumnName() {
        return pkcolumnName;
    }

    /**
     * CROSS_REFERENCES.PKCOLUMN_NAME
     *
     * @param pkcolumnName
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setPkcolumnName(String pkcolumnName) {
        this.pkcolumnName = pkcolumnName == null ? null : pkcolumnName.trim();
    }

    /**
     * @return CROSS_REFERENCES.FKTABLE_CATALOG
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getFktableCatalog() {
        return fktableCatalog;
    }

    /**
     * CROSS_REFERENCES.FKTABLE_CATALOG
     *
     * @param fktableCatalog
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setFktableCatalog(String fktableCatalog) {
        this.fktableCatalog = fktableCatalog == null ? null : fktableCatalog.trim();
    }

    /**
     * @return CROSS_REFERENCES.FKTABLE_SCHEMA
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getFktableSchema() {
        return fktableSchema;
    }

    /**
     * CROSS_REFERENCES.FKTABLE_SCHEMA
     *
     * @param fktableSchema
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setFktableSchema(String fktableSchema) {
        this.fktableSchema = fktableSchema == null ? null : fktableSchema.trim();
    }

    /**
     * @return CROSS_REFERENCES.FKTABLE_NAME
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getFktableName() {
        return fktableName;
    }

    /**
     * CROSS_REFERENCES.FKTABLE_NAME
     *
     * @param fktableName
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setFktableName(String fktableName) {
        this.fktableName = fktableName == null ? null : fktableName.trim();
    }

    /**
     * @return CROSS_REFERENCES.FKCOLUMN_NAME
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getFkcolumnName() {
        return fkcolumnName;
    }

    /**
     * CROSS_REFERENCES.FKCOLUMN_NAME
     *
     * @param fkcolumnName
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setFkcolumnName(String fkcolumnName) {
        this.fkcolumnName = fkcolumnName == null ? null : fkcolumnName.trim();
    }

    /**
     * @return CROSS_REFERENCES.ORDINAL_POSITION
     * @mbggenerated 2014-03-10 10:45:44
     */
    public Short getOrdinalPosition() {
        return ordinalPosition;
    }

    /**
     * CROSS_REFERENCES.ORDINAL_POSITION
     *
     * @param ordinalPosition
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setOrdinalPosition(Short ordinalPosition) {
        this.ordinalPosition = ordinalPosition;
    }

    /**
     * @return CROSS_REFERENCES.UPDATE_RULE
     * @mbggenerated 2014-03-10 10:45:44
     */
    public Short getUpdateRule() {
        return updateRule;
    }

    /**
     * CROSS_REFERENCES.UPDATE_RULE
     *
     * @param updateRule
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setUpdateRule(Short updateRule) {
        this.updateRule = updateRule;
    }

    /**
     * @return CROSS_REFERENCES.DELETE_RULE
     * @mbggenerated 2014-03-10 10:45:44
     */
    public Short getDeleteRule() {
        return deleteRule;
    }

    /**
     * CROSS_REFERENCES.DELETE_RULE
     *
     * @param deleteRule
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setDeleteRule(Short deleteRule) {
        this.deleteRule = deleteRule;
    }

    /**
     * @return CROSS_REFERENCES.FK_NAME
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getFkName() {
        return fkName;
    }

    /**
     * CROSS_REFERENCES.FK_NAME
     *
     * @param fkName
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setFkName(String fkName) {
        this.fkName = fkName == null ? null : fkName.trim();
    }

    /**
     * @return CROSS_REFERENCES.PK_NAME
     * @mbggenerated 2014-03-10 10:45:44
     */
    public String getPkName() {
        return pkName;
    }

    /**
     * CROSS_REFERENCES.PK_NAME
     *
     * @param pkName
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setPkName(String pkName) {
        this.pkName = pkName == null ? null : pkName.trim();
    }

    /**
     * @return CROSS_REFERENCES.DEFERRABILITY
     * @mbggenerated 2014-03-10 10:45:44
     */
    public Short getDeferrability() {
        return deferrability;
    }

    /**
     * CROSS_REFERENCES.DEFERRABILITY
     *
     * @param deferrability
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setDeferrability(Short deferrability) {
        this.deferrability = deferrability;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:44
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        CrossReferences other = (CrossReferences) that;
        return (this.getPktableCatalog() == null ? other.getPktableCatalog() == null : this.getPktableCatalog().equals(other.getPktableCatalog()))
            && (this.getPktableSchema() == null ? other.getPktableSchema() == null : this.getPktableSchema().equals(other.getPktableSchema()))
            && (this.getPktableName() == null ? other.getPktableName() == null : this.getPktableName().equals(other.getPktableName()))
            && (this.getPkcolumnName() == null ? other.getPkcolumnName() == null : this.getPkcolumnName().equals(other.getPkcolumnName()))
            && (this.getFktableCatalog() == null ? other.getFktableCatalog() == null : this.getFktableCatalog().equals(other.getFktableCatalog()))
            && (this.getFktableSchema() == null ? other.getFktableSchema() == null : this.getFktableSchema().equals(other.getFktableSchema()))
            && (this.getFktableName() == null ? other.getFktableName() == null : this.getFktableName().equals(other.getFktableName()))
            && (this.getFkcolumnName() == null ? other.getFkcolumnName() == null : this.getFkcolumnName().equals(other.getFkcolumnName()))
            && (this.getOrdinalPosition() == null ? other.getOrdinalPosition() == null : this.getOrdinalPosition().equals(other.getOrdinalPosition()))
            && (this.getUpdateRule() == null ? other.getUpdateRule() == null : this.getUpdateRule().equals(other.getUpdateRule()))
            && (this.getDeleteRule() == null ? other.getDeleteRule() == null : this.getDeleteRule().equals(other.getDeleteRule()))
            && (this.getFkName() == null ? other.getFkName() == null : this.getFkName().equals(other.getFkName()))
            && (this.getPkName() == null ? other.getPkName() == null : this.getPkName().equals(other.getPkName()))
            && (this.getDeferrability() == null ? other.getDeferrability() == null : this.getDeferrability().equals(other.getDeferrability()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:44
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPktableCatalog() == null) ? 0 : getPktableCatalog().hashCode());
        result = prime * result + ((getPktableSchema() == null) ? 0 : getPktableSchema().hashCode());
        result = prime * result + ((getPktableName() == null) ? 0 : getPktableName().hashCode());
        result = prime * result + ((getPkcolumnName() == null) ? 0 : getPkcolumnName().hashCode());
        result = prime * result + ((getFktableCatalog() == null) ? 0 : getFktableCatalog().hashCode());
        result = prime * result + ((getFktableSchema() == null) ? 0 : getFktableSchema().hashCode());
        result = prime * result + ((getFktableName() == null) ? 0 : getFktableName().hashCode());
        result = prime * result + ((getFkcolumnName() == null) ? 0 : getFkcolumnName().hashCode());
        result = prime * result + ((getOrdinalPosition() == null) ? 0 : getOrdinalPosition().hashCode());
        result = prime * result + ((getUpdateRule() == null) ? 0 : getUpdateRule().hashCode());
        result = prime * result + ((getDeleteRule() == null) ? 0 : getDeleteRule().hashCode());
        result = prime * result + ((getFkName() == null) ? 0 : getFkName().hashCode());
        result = prime * result + ((getPkName() == null) ? 0 : getPkName().hashCode());
        result = prime * result + ((getDeferrability() == null) ? 0 : getDeferrability().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:44
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", pktableCatalog=").append(pktableCatalog);
        sb.append(", pktableSchema=").append(pktableSchema);
        sb.append(", pktableName=").append(pktableName);
        sb.append(", pkcolumnName=").append(pkcolumnName);
        sb.append(", fktableCatalog=").append(fktableCatalog);
        sb.append(", fktableSchema=").append(fktableSchema);
        sb.append(", fktableName=").append(fktableName);
        sb.append(", fkcolumnName=").append(fkcolumnName);
        sb.append(", ordinalPosition=").append(ordinalPosition);
        sb.append(", updateRule=").append(updateRule);
        sb.append(", deleteRule=").append(deleteRule);
        sb.append(", fkName=").append(fkName);
        sb.append(", pkName=").append(pkName);
        sb.append(", deferrability=").append(deferrability);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/CrossReferences.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class CrossReferences extends GenericDPSObject {
    /**
     * CROSS_REFERENCES.PKTABLE_CATALOG
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String pktableCatalog;

    /**
     * CROSS_REFERENCES.PKTABLE_SCHEMA
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String pktableSchema;

    /**
     * CROSS_REFERENCES.PKTABLE_NAME
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String pktableName;

    /**
     * CROSS_REFERENCES.PKCOLUMN_NAME
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String pkcolumnName;

    /**
     * CROSS_REFERENCES.FKTABLE_CATALOG
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String fktableCatalog;

    /**
     * CROSS_REFERENCES.FKTABLE_SCHEMA
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String fktableSchema;

    /**
     * CROSS_REFERENCES.FKTABLE_NAME
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String fktableName;

    /**
     * CROSS_REFERENCES.FKCOLUMN_NAME
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String fkcolumnName;

    /**
     * CROSS_REFERENCES.ORDINAL_POSITION
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private Short ordinalPosition;

    /**
     * CROSS_REFERENCES.UPDATE_RULE
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private Short updateRule;

    /**
     * CROSS_REFERENCES.DELETE_RULE
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private Short deleteRule;

    /**
     * CROSS_REFERENCES.FK_NAME
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String fkName;

    /**
     * CROSS_REFERENCES.PK_NAME
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private String pkName;

    /**
     * CROSS_REFERENCES.DEFERRABILITY
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private Short deferrability;

    /**
     * @mbggenerated 2014-03-13 16:02:50
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return CROSS_REFERENCES.PKTABLE_CATALOG
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getPktableCatalog() {
        return pktableCatalog;
    }

    /**
     * CROSS_REFERENCES.PKTABLE_CATALOG
     *
     * @param pktableCatalog
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setPktableCatalog(String pktableCatalog) {
        this.pktableCatalog = pktableCatalog == null ? null : pktableCatalog.trim();
    }

    /**
     * @return CROSS_REFERENCES.PKTABLE_SCHEMA
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getPktableSchema() {
        return pktableSchema;
    }

    /**
     * CROSS_REFERENCES.PKTABLE_SCHEMA
     *
     * @param pktableSchema
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setPktableSchema(String pktableSchema) {
        this.pktableSchema = pktableSchema == null ? null : pktableSchema.trim();
    }

    /**
     * @return CROSS_REFERENCES.PKTABLE_NAME
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getPktableName() {
        return pktableName;
    }

    /**
     * CROSS_REFERENCES.PKTABLE_NAME
     *
     * @param pktableName
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setPktableName(String pktableName) {
        this.pktableName = pktableName == null ? null : pktableName.trim();
    }

    /**
     * @return CROSS_REFERENCES.PKCOLUMN_NAME
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getPkcolumnName() {
        return pkcolumnName;
    }

    /**
     * CROSS_REFERENCES.PKCOLUMN_NAME
     *
     * @param pkcolumnName
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setPkcolumnName(String pkcolumnName) {
        this.pkcolumnName = pkcolumnName == null ? null : pkcolumnName.trim();
    }

    /**
     * @return CROSS_REFERENCES.FKTABLE_CATALOG
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getFktableCatalog() {
        return fktableCatalog;
    }

    /**
     * CROSS_REFERENCES.FKTABLE_CATALOG
     *
     * @param fktableCatalog
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setFktableCatalog(String fktableCatalog) {
        this.fktableCatalog = fktableCatalog == null ? null : fktableCatalog.trim();
    }

    /**
     * @return CROSS_REFERENCES.FKTABLE_SCHEMA
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getFktableSchema() {
        return fktableSchema;
    }

    /**
     * CROSS_REFERENCES.FKTABLE_SCHEMA
     *
     * @param fktableSchema
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setFktableSchema(String fktableSchema) {
        this.fktableSchema = fktableSchema == null ? null : fktableSchema.trim();
    }

    /**
     * @return CROSS_REFERENCES.FKTABLE_NAME
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getFktableName() {
        return fktableName;
    }

    /**
     * CROSS_REFERENCES.FKTABLE_NAME
     *
     * @param fktableName
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setFktableName(String fktableName) {
        this.fktableName = fktableName == null ? null : fktableName.trim();
    }

    /**
     * @return CROSS_REFERENCES.FKCOLUMN_NAME
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getFkcolumnName() {
        return fkcolumnName;
    }

    /**
     * CROSS_REFERENCES.FKCOLUMN_NAME
     *
     * @param fkcolumnName
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setFkcolumnName(String fkcolumnName) {
        this.fkcolumnName = fkcolumnName == null ? null : fkcolumnName.trim();
    }

    /**
     * @return CROSS_REFERENCES.ORDINAL_POSITION
     * @mbggenerated 2014-03-13 16:02:50
     */
    public Short getOrdinalPosition() {
        return ordinalPosition;
    }

    /**
     * CROSS_REFERENCES.ORDINAL_POSITION
     *
     * @param ordinalPosition
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setOrdinalPosition(Short ordinalPosition) {
        this.ordinalPosition = ordinalPosition;
    }

    /**
     * @return CROSS_REFERENCES.UPDATE_RULE
     * @mbggenerated 2014-03-13 16:02:50
     */
    public Short getUpdateRule() {
        return updateRule;
    }

    /**
     * CROSS_REFERENCES.UPDATE_RULE
     *
     * @param updateRule
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setUpdateRule(Short updateRule) {
        this.updateRule = updateRule;
    }

    /**
     * @return CROSS_REFERENCES.DELETE_RULE
     * @mbggenerated 2014-03-13 16:02:50
     */
    public Short getDeleteRule() {
        return deleteRule;
    }

    /**
     * CROSS_REFERENCES.DELETE_RULE
     *
     * @param deleteRule
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setDeleteRule(Short deleteRule) {
        this.deleteRule = deleteRule;
    }

    /**
     * @return CROSS_REFERENCES.FK_NAME
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getFkName() {
        return fkName;
    }

    /**
     * CROSS_REFERENCES.FK_NAME
     *
     * @param fkName
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setFkName(String fkName) {
        this.fkName = fkName == null ? null : fkName.trim();
    }

    /**
     * @return CROSS_REFERENCES.PK_NAME
     * @mbggenerated 2014-03-13 16:02:50
     */
    public String getPkName() {
        return pkName;
    }

    /**
     * CROSS_REFERENCES.PK_NAME
     *
     * @param pkName
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setPkName(String pkName) {
        this.pkName = pkName == null ? null : pkName.trim();
    }

    /**
     * @return CROSS_REFERENCES.DEFERRABILITY
     * @mbggenerated 2014-03-13 16:02:50
     */
    public Short getDeferrability() {
        return deferrability;
    }

    /**
     * CROSS_REFERENCES.DEFERRABILITY
     *
     * @param deferrability
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setDeferrability(Short deferrability) {
        this.deferrability = deferrability;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:50
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        CrossReferences other = (CrossReferences) that;
        return (this.getPktableCatalog() == null ? other.getPktableCatalog() == null : this.getPktableCatalog().equals(other.getPktableCatalog()))
            && (this.getPktableSchema() == null ? other.getPktableSchema() == null : this.getPktableSchema().equals(other.getPktableSchema()))
            && (this.getPktableName() == null ? other.getPktableName() == null : this.getPktableName().equals(other.getPktableName()))
            && (this.getPkcolumnName() == null ? other.getPkcolumnName() == null : this.getPkcolumnName().equals(other.getPkcolumnName()))
            && (this.getFktableCatalog() == null ? other.getFktableCatalog() == null : this.getFktableCatalog().equals(other.getFktableCatalog()))
            && (this.getFktableSchema() == null ? other.getFktableSchema() == null : this.getFktableSchema().equals(other.getFktableSchema()))
            && (this.getFktableName() == null ? other.getFktableName() == null : this.getFktableName().equals(other.getFktableName()))
            && (this.getFkcolumnName() == null ? other.getFkcolumnName() == null : this.getFkcolumnName().equals(other.getFkcolumnName()))
            && (this.getOrdinalPosition() == null ? other.getOrdinalPosition() == null : this.getOrdinalPosition().equals(other.getOrdinalPosition()))
            && (this.getUpdateRule() == null ? other.getUpdateRule() == null : this.getUpdateRule().equals(other.getUpdateRule()))
            && (this.getDeleteRule() == null ? other.getDeleteRule() == null : this.getDeleteRule().equals(other.getDeleteRule()))
            && (this.getFkName() == null ? other.getFkName() == null : this.getFkName().equals(other.getFkName()))
            && (this.getPkName() == null ? other.getPkName() == null : this.getPkName().equals(other.getPkName()))
            && (this.getDeferrability() == null ? other.getDeferrability() == null : this.getDeferrability().equals(other.getDeferrability()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:50
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPktableCatalog() == null) ? 0 : getPktableCatalog().hashCode());
        result = prime * result + ((getPktableSchema() == null) ? 0 : getPktableSchema().hashCode());
        result = prime * result + ((getPktableName() == null) ? 0 : getPktableName().hashCode());
        result = prime * result + ((getPkcolumnName() == null) ? 0 : getPkcolumnName().hashCode());
        result = prime * result + ((getFktableCatalog() == null) ? 0 : getFktableCatalog().hashCode());
        result = prime * result + ((getFktableSchema() == null) ? 0 : getFktableSchema().hashCode());
        result = prime * result + ((getFktableName() == null) ? 0 : getFktableName().hashCode());
        result = prime * result + ((getFkcolumnName() == null) ? 0 : getFkcolumnName().hashCode());
        result = prime * result + ((getOrdinalPosition() == null) ? 0 : getOrdinalPosition().hashCode());
        result = prime * result + ((getUpdateRule() == null) ? 0 : getUpdateRule().hashCode());
        result = prime * result + ((getDeleteRule() == null) ? 0 : getDeleteRule().hashCode());
        result = prime * result + ((getFkName() == null) ? 0 : getFkName().hashCode());
        result = prime * result + ((getPkName() == null) ? 0 : getPkName().hashCode());
        result = prime * result + ((getDeferrability() == null) ? 0 : getDeferrability().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:50
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", pktableCatalog=").append(pktableCatalog);
        sb.append(", pktableSchema=").append(pktableSchema);
        sb.append(", pktableName=").append(pktableName);
        sb.append(", pkcolumnName=").append(pkcolumnName);
        sb.append(", fktableCatalog=").append(fktableCatalog);
        sb.append(", fktableSchema=").append(fktableSchema);
        sb.append(", fktableName=").append(fktableName);
        sb.append(", fkcolumnName=").append(fkcolumnName);
        sb.append(", ordinalPosition=").append(ordinalPosition);
        sb.append(", updateRule=").append(updateRule);
        sb.append(", deleteRule=").append(deleteRule);
        sb.append(", fkName=").append(fkName);
        sb.append(", pkName=").append(pkName);
        sb.append(", deferrability=").append(deferrability);
        sb.append("]");
        return sb.toString();
    }
}
